import { Component, EventEmitter, Input, Output } from '@angular/core';
var AngularRaveComponent = /** @class */ (function () {
    function AngularRaveComponent() {
        this.onclose = new EventEmitter();
        this.callback = new EventEmitter();
    }
    AngularRaveComponent.prototype.pay = function () {
        if (typeof window.getpaidSetup !== "function") {
            return console.error("Please verify that you imported rave's script into your index.html");
        }
        // If the raveoptions Input is present then use
        if (this.raveOptions && Object.keys(this.raveOptions).length > 3) {
            if (!this.validateOptions()) {
                return;
            }
            window.getpaidSetup(this.raveOptions);
        }
        else {
            if (!this.validateInput()) {
                return;
            }
            this.insertRaveOptions();
            window.getpaidSetup(this._raveOptions);
        }
    };
    AngularRaveComponent.prototype.insertRaveOptions = function () {
        var _this = this;
        this.amount ? this._raveOptions.amount = this.amount : null;
        this.PBFPubKey ? this._raveOptions.PBFPubKey = this.PBFPubKey : null;
        this.payment_method ? this._raveOptions.payment_method = this.payment_method : null;
        this.redirect_url ? this._raveOptions.redirect_url = this.redirect_url : null;
        this.integrity_hash ? this._raveOptions.integrity_hash = this.integrity_hash : null;
        this.pay_button_text ? this._raveOptions.pay_button_text = this.pay_button_text : null;
        this.country ? this._raveOptions.country = this.country : null;
        this.currency ? this._raveOptions.currency = this.currency : null;
        this.custom_description ? this._raveOptions.custom_description = this.custom_description : null;
        this.customer_email ? this._raveOptions.customer_email = this.customer_email : null;
        this.custom_logo ? this._raveOptions.custom_logo = this.custom_logo : null;
        this.custom_title ? this._raveOptions.custom_title = this.custom_title : null;
        this.customer_firstname ? this._raveOptions.customer_firstname = this.customer_firstname : null;
        this.customer_lastname ? this._raveOptions.customer_lastname = this.customer_lastname : null;
        this.txref ? this._raveOptions.txref = this.txref : null;
        this.customer_phone ? this._raveOptions.customer_phone = this.customer_phone : null;
        this.onclose ? this._raveOptions.onclose = function () { return _this.onclose.emit(); } : null;
        this.callback ? this._raveOptions.callback = function (res) { return _this.onclose.emit(res); } : null;
    };
    AngularRaveComponent.prototype.validateOptions = function () {
        var _this = this;
        if (!this.raveOptions.PBFPubKey)
            return console.error("Merchant public key is required");
        if (!(this.raveOptions.customer_email || this.raveOptions.customer_phone))
            return console.error("Customer email or phone number is required");
        if (!this.raveOptions.txref)
            return console.error("A unique transaction reference is required");
        if (!this.raveOptions.amount)
            return console.error("Amount to charge is required");
        // Remove callback and onClose from options
        if (typeof this.raveOptions.callback === "function") {
            delete this.raveOptions.callback;
        }
        if (typeof this.raveOptions.onclose === "function") {
            delete this.raveOptions.onclose;
        }
        this.raveOptions.onclose = function () { return _this.onclose.emit(); };
        this.raveOptions.callback = function (res) { return _this.onclose.emit(res); };
        if (!this.callback)
            return console.error("You should attach to callback to verify your transaction");
        return true;
    };
    AngularRaveComponent.prototype.validateInput = function () {
        if (!this.PBFPubKey)
            return console.error("Merchant public key is required");
        if (!(this.customer_email || this.customer_phone))
            return console.error("Customer email or phone number is required");
        if (!this.txref)
            return console.error("A unique transaction reference is required");
        if (!this.amount)
            return console.error("Amount to charge is required");
        if (!this.callback)
            return console.error("You should attach to callback to verify your transaction");
        return true;
    };
    AngularRaveComponent.prototype.ngOnInit = function () {
        this.pay();
    };
    AngularRaveComponent.decorators = [
        { type: Component, args: [{
                    selector: 'angular-rave',
                    template: "<div></div>"
                },] },
    ];
    /** @nocollapse */
    AngularRaveComponent.ctorParameters = function () { return []; };
    AngularRaveComponent.propDecorators = {
        'PBFPubKey': [{ type: Input },],
        'integrity_hash': [{ type: Input },],
        'txref': [{ type: Input },],
        'payment_method': [{ type: Input },],
        'amount': [{ type: Input },],
        'currency': [{ type: Input },],
        'country': [{ type: Input },],
        'customer_email': [{ type: Input },],
        'customer_phone': [{ type: Input },],
        'customer_firstname': [{ type: Input },],
        'customer_lastname': [{ type: Input },],
        'pay_button_text': [{ type: Input },],
        'custom_title': [{ type: Input },],
        'custom_description': [{ type: Input },],
        'redirect_url': [{ type: Input },],
        'custom_logo': [{ type: Input },],
        'meta': [{ type: Input },],
        'raveOptions': [{ type: Input },],
        'onclose': [{ type: Output },],
        'callback': [{ type: Output },],
    };
    return AngularRaveComponent;
}());
export { AngularRaveComponent };
